@@ -17,7 +17,7 @@ use tokio::time;
 use utils::*;
 use xor_name::XOR_NAME_LEN;
 /*
-#[tokio::test]
+#[tokio::test(flavor = "multi_thread")]
 async fn test_genesis_node() -> Result<()> {
     let keypair = Keypair::generate(&mut rand::thread_rng());
     let (node, mut event_stream) = create_node(Config {
@@ -36,7 +36,7 @@ async fn test_genesis_node() -> Result<()> {
     Ok(())
 }
 
-#[tokio::test]
+#[tokio::test(flavor = "multi_thread")]
 async fn test_node_bootstrapping() -> Result<()> {
     let (genesis_node, mut event_stream) = create_node(Config {
         first: true,
@@ -65,7 +65,7 @@ async fn test_node_bootstrapping() -> Result<()> {
     Ok(())
 }
 
-#[tokio::test]
+#[tokio::test(flavor = "multi_thread")]
 async fn test_startup_section_bootstrapping() -> Result<()> {
     // Create the genesis node.
     let (genesis_node, mut event_stream) = create_node(Config {
@@ -117,7 +117,7 @@ async fn test_startup_section_bootstrapping() -> Result<()> {
 }
 
 // Test that the first `ELDER_SIZE` nodes in the network are promoted to elders.
-#[tokio::test]
+#[tokio::test(flavor = "multi_thread")]
 async fn test_startup_elders() -> Result<()> {
     let mut nodes = create_connected_nodes(ELDER_SIZE).await?;
 
